################
Sphinx-Terraform
################

.. container:: tagline

    A Sphinx_ extension for documenting **Terraform** modules.

.. container:: center

        |docs_badge| |test_badge| |lic_badge| |pypi_badge| |download_badge| |black_badge|

.. |docs_badge| image:: https://gitlab.com/cblegare/sphinx-terraform/badges/main/pipeline.svg?job=pages&key_text=docs
    :target: https://gitlab.com/cblegare/sphinx-terraform/-/pipelines
    :alt: Gitlab - Docs

.. |test_badge| image:: https://gitlab.com/cblegare/sphinx-terraform/badges/main/coverage.svg?job=coverage
    :target: https://gitlab.com/cblegare/sphinx-terraform/-/pipelines
    :alt: Gitlab - Coverage

.. |lic_badge| image:: https://img.shields.io/pypi/l/sphinx-terraform?color=blue
    :target: https://gitlab.com/cblegare/sphinx-terraform/-/blob/main/LICENSE
    :alt: PyPI - License

.. |release_badge| image:: https://gitlab.com/cblegare/sphinx-terraform/-/badges/release.svg
    :target: https://gitlab.com/cblegare/sphinx-terraform/-/releases
    :alt: Gitlab - Release

.. |pypi_badge| image:: https://img.shields.io/pypi/v/sphinx-terraform
    :target: https://pypi.org/project/sphinx-terraform
    :alt: PyPI - Release

.. |download_badge| image:: https://img.shields.io/pypi/dm/sphinx-terraform
    :target: https://pypi.org/project/sphinx-terraform/
    :alt: PyPI - Downloads

.. |black_badge| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Formatting - Black

**Sphinx-Terraform** is simple to use and integrate smoothly with your Terraform codebase.

    Programs must be written for people to read, and only incidentally
    for machines to execute.

    -- `SICP <https://mitpress.mit.edu/sites/default/files/sicp/index.html>`__


Code can become reusable when it is clearly visible, searchable and
referenceable.  **Sphinx-Terraform** will help

*   **make reusable modules** that application developers will find easier
    to find, understand and use, thus reducing bugs, support time and *toil*;

*   **show value to stakeholders**, since Infrastructure as Code is an abstract
    and obscure topic for non-practitioners;

*   **promote knowledge** and foster a community spirit around your code;

*   **keep track** of *why* things work the way they do.

----

`Read the documentation! <documentation>`_

**Sphinx-Terraform** is

- `Hosted on Gitlab <https://gitlab.com/cblegare/sphinx-terraform>`__
- `Mirrored on Github <https://github.com/cblegare/sphinx-terraform>`__
- `Distributed on PyPI <https://pypi.org/project/sphinx-terraform/>`__
- `Documented online <https://cblegare.gitlab.io/sphinx-terraform/>`__

.. _Sphinx: https://www.sphinx-doc.org/en/master/index.html
.. _HashiCorp: https://www.hashicorp.com/
.. _documentation: https://cblegare.gitlab.io/sphinx-terraform
